<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# typemax

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Return the maximum value of a specified numeric type.

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="installation">

## Installation

```bash
npm install @stdlib/utils-type-max
```

</section>

<section class="usage">

## Usage

```javascript
var typemax = require( '@stdlib/utils-type-max' );
```

#### typemax( dtype )

Returns the maximum value of a specified numeric type.

```javascript
var m = typemax( 'int8' );
// returns 127
```

The following numeric types are supported:

-   `float64`: double-precision floating-point numbers
-   `float32`: single-precision floating-point numbers
-   `float16`: half-precision floating-point numbers
-   `int32`: 32-bit two's complement signed integers
-   `uint32`: 32-bit unsigned integers
-   `int16`: 16-bit two's complement signed integers
-   `uint16`: 16-bit unsigned integers
-   `int8`: 8-bit two's complement signed integers
-   `uint8`: 8-bit unsigned integers
-   `uint8c`: 8-bit unsigned integers clamped to `0-255`

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var typemax = require( '@stdlib/utils-type-max' );

var m = typemax( 'float64' );
// returns Infinity

m = typemax( 'float32' );
// returns Infinity

m = typemax( 'float16' );
// returns Infinity

m = typemax( 'int32' );
// returns 2147483647

m = typemax( 'uint32' );
// returns 4294967295

m = typemax( 'int16' );
// returns 32767

m = typemax( 'uint16' );
// returns 65535

m = typemax( 'int8' );
// returns 127

m = typemax( 'uint8' );
// returns 255

m = typemax( 'uint8c' );
// returns 255
```

</section>

<!-- /.examples -->

<!-- Section for describing a command-line interface. -->



<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

## See Also

-   <span class="package-name">[`@stdlib/utils-type-max-cli`][@stdlib/utils-type-max-cli]</span><span class="delimiter">: </span><span class="description">CLI package for use as a command-line utility.</span>
-   <span class="package-name">[`@stdlib/utils-real-max`][@stdlib/utils/real-max]</span><span class="delimiter">: </span><span class="description">return the maximum finite value capable of being represented by a numeric real type.</span>
-   <span class="package-name">[`@stdlib/utils-type-min`][@stdlib/utils/type-min]</span><span class="delimiter">: </span><span class="description">return the minimum value of a specified numeric type.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2023. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[@stdlib/utils-type-max-cli]: https://www.npmjs.com/package/@stdlib/utils-type-max-cli

[npm-image]: http://img.shields.io/npm/v/@stdlib/utils-type-max.svg
[npm-url]: https://npmjs.org/package/@stdlib/utils-type-max

[test-image]: https://github.com/stdlib-js/utils-type-max/actions/workflows/test.yml/badge.svg?branch=v0.1.1
[test-url]: https://github.com/stdlib-js/utils-type-max/actions/workflows/test.yml?query=branch:v0.1.1

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/utils-type-max/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/utils-type-max?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/utils-type-max.svg
[dependencies-url]: https://david-dm.org/stdlib-js/utils-type-max/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[cli-section]: https://github.com/stdlib-js/utils-type-max#cli
[cli-url]: https://github.com/stdlib-js/utils-type-max/tree/cli
[@stdlib/utils-type-max]: https://github.com/stdlib-js/utils-type-max/tree/main

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/utils-type-max/tree/deno
[umd-url]: https://github.com/stdlib-js/utils-type-max/tree/umd
[esm-url]: https://github.com/stdlib-js/utils-type-max/tree/esm
[branches-url]: https://github.com/stdlib-js/utils-type-max/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/utils-type-max/main/LICENSE

<!-- <related-links> -->

[@stdlib/utils/real-max]: https://www.npmjs.com/package/@stdlib/utils-real-max

[@stdlib/utils/type-min]: https://www.npmjs.com/package/@stdlib/utils-type-min

<!-- </related-links> -->

</section>

<!-- /.links -->
